# Import Section
import sys
import json
import requests
# --------------


def get_uuid_api(username):
    api_url_base = 'https://api.mojang.com/users/profiles/minecraft/' + username
    response = requests.get(f"{api_url_base}")
    if response.status_code == 404:
        return "Username is not registered, its free or Input is Illegal"
        exit(1)
    else:
        uuid = json.dumps(response.json())
        if uuid[0] == "-":
            uuid = uuid[1:]
        uuid_hyphen = uuid[:8] + '-' + uuid[8:12] + '-' + uuid[12:16] + '-' + uuid[16:20] + '-' + uuid[20:]
        return uuid_hyphen
        #return json.dumps(response.json())




import sys
import argparse
from mc_uuid_check import mc_offline_uuid as offmcuuid
from mc_uuid_check import mc_online_uuid as onmcuuid
from mc_uuid_check import helperfunctions as helper


parser = argparse.ArgumentParser(
    prog='mc-uuid-check',
    description='Get the Offline / Online UUID of a Player')
parser.add_argument("-o", "--online", action="store_true", help="Check Mojang API for UUID")
parser.add_argument("-r", "--without-hyphen", dest="wouthyph", action="store_true", help="Removes Hyphen from UUID String")
parser.add_argument("username", type=str, help="Username of the Player")
args = parser.parse_args()

username = args.username


def main():
    #Getting argument from command line as username to convert
    #Printing UUID
    if args.online:
        stringinput = helper.format_json(onmcuuid.get_uuid_api(username))
        if args.wouthyph:
            print(helper.rem_hyphen(stringinput))
        else:
            print(stringinput)
    else:
        if args.wouthyph:
            print(helper.rem_hyphen(offmcuuid.get_uuid_offline(username)))
        else:
            print(offmcuuid.get_uuid_offline(username))


if __name__ == "__main__":
    main(username)




import uuid
import hashlib


def get_uuid_offline(username):
    # This Code is translated to Python from the Java Function in the Sourcecode of Minecraft
    offline_uuid = uuid.UUID(hashlib.md5(f"OfflinePlayer:{username}".encode('utf-8')).hexdigest())
    formated_uuid = str(offline_uuid)
    formatted_output = f"Name: {username}\nUUID: {formated_uuid}"
    return formatted_output




import json


def format_json(jsondata):
	data = json.loads(jsondata)
	output = f"Name: {data['name']}\nUUID: {data['id']}"
	return output


def rem_hyphen(instring):
	return str(instring).replace('-', '')

